@@ -8,9 +8,8 @@
 #' num_hash()
 #' signed_hash()
 #' @export
-#' @export
 #' @rdname texthash
-num_hash <- function(range = c(8, 12), trans = log2_trans()) {
+num_hash <- function(range = c(8L, 12L), trans = log2_trans()) {
   new_quant_param(
     type = "integer",
     range = range,
